==> net.bluemind.p2.platform-4.9.3879.zip: net/bluemind/sds/dto/SdsResponse.java <==
/* BEGIN LICENSE
  * Copyright © Blue Mind SAS, 2012-2019
  *
  * This file is part of BlueMind. BlueMind is a messaging and collaborative
  * solution.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of either the GNU Affero General Public License as
  * published by the Free Software Foundation (version 3 of the License).
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  *
  * See LICENSE.txt
  * END LICENSE
  */
package net.bluemind.sds.dto;

import java.util.Collections;
import java.util.Map;

import com.fasterxml.jackson.annotation.JsonProperty;
import com.google.common.base.MoreObjects;

public class SdsResponse {

	public static final SdsResponse UNTAGGED_OK = new SdsResponse() {
		@Override
		public SdsResponse withTags(Map<String, String> t) {
			return this;
		}
	};

	public SdsError error;
	private Map<String, String> tags = Collections.emptyMap();
	private long size = 0;

	public boolean succeeded() {
		return error == null;
	}

	@Override
	public String toString() {
		return MoreObjects.toStringHelper(getClass()).add("success", succeeded()).add("error", error).toString();
	}

	public SdsResponse withTags(Map<String, String> t) {
		this.tags = t;
		return this;
	}

	public SdsResponse withSize(long size) {
		this.size = size;
		return this;
	}

	@JsonProperty("tags")
	public Map<String, String> tags() {
		return tags;
	}

	@JsonProperty("size")
	public long size() {
		return size;
	}

}

==> net.bluemind.p2.platform-5.5.3184.zip: net/bluemind/sds/dto/SdsResponse.java <==
/* BEGIN LICENSE
  * Copyright © Blue Mind SAS, 2012-2019
  *
  * This file is part of BlueMind. BlueMind is a messaging and collaborative
  * solution.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of either the GNU Affero General Public License as
  * published by the Free Software Foundation (version 3 of the License).
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  *
  * See LICENSE.txt
  * END LICENSE
  */
package net.bluemind.sds.dto;

import java.util.Collections;
import java.util.List;
import java.util.Map;

import com.fasterxml.jackson.annotation.JsonProperty;
import com.google.common.base.MoreObjects;

public class SdsResponse {

	public static final SdsResponse UNTAGGED_OK = new SdsResponse() {
		@Override
		public SdsResponse withTags(Map<String, String> t) {
			return this;
		}

		@Override
		public SdsResponse withSize(long size) {
			return this;
		}
	};

	public static SdsResponse sdsResponseWithSize(long size) {
		SdsResponse response = new SdsResponse();
		response.size = size;
		return response;
	}

	public static SdsResponse error(Throwable t, String guid, boolean retryable) {
		SdsResponse response = new SdsResponse();
		response.error = new SdsError(t.getMessage(), guid, retryable);
		return response;
	}

	public static SdsResponse error(String message, String guid, boolean retryable) {
		SdsResponse response = new SdsResponse();
		response.error = new SdsError(message, guid, retryable);
		return response;
	}

	public static SdsResponse error(String message, List<String> guids, boolean retryable) {
		SdsResponse response = new SdsResponse();
		response.error = new SdsError(message, guids, retryable);
		return response;
	}

	public SdsError error;
	private Map<String, String> tags = Collections.emptyMap();
	private long size = 0;

	public boolean succeeded() {
		return error == null;
	}

	@Override
	public String toString() {
		return MoreObjects.toStringHelper(getClass()).add("success", succeeded()).add("error", error).toString();
	}

	public SdsResponse withTags(Map<String, String> t) {
		this.tags = t;
		return this;
	}

	public SdsResponse withSize(long size) {
		this.size = size;
		return this;
	}

	@JsonProperty("tags")
	public Map<String, String> tags() {
		return tags;
	}

	@JsonProperty("size")
	public long size() {
		return size;
	}

}
